pub enum ChallengeKind {
Supersession,
Contradiction,
Retraction,
Expiration,
}Expand description
What kind of write the incumbent was challenged by (ADR 0015). Only challenges that
were real contests lost on strength are recorded — see ChallengeRejection.
Variants